@@ -4,7 +4,7 @@ g.analyse.perfile = function(ID, ID2, IDd, fname, deviceSerialNumber, BodyLocati
                   daysummary, ds_names, includedaycrit, strategy, hrs.del.start,
                   hrs.del.end, maxdur, windowsizes, idloc, snloc, wdayname, doquan,
                   qlevels_names, doiglevels, tooshort, InterdailyStability, IntradailyVariability,
-                  IVIS_windowsize_minutes, IVIS_epochsize_seconds, qwindow) {
+                  IVIS_windowsize_minutes, IVIS_epochsize_seconds, qwindow, longitudinal_axis_id) {
   filesummary = matrix(" ",1,100) #matrix to be stored with summary per participant
   s_names = rep(" ",ncol(filesummary))
   vi = 1
@@ -189,21 +189,22 @@ g.analyse.perfile = function(ID, ID2, IDd, fname, deviceSerialNumber, BodyLocati
     filesummary[(vi+2)] = hrs.del.end
     filesummary[(vi+3)] = maxdur
     filesummary[(vi+4)] = windowsizes[1]
+    filesummary[(vi+5)] = longitudinal_axis_id
     #get GGIR version
     SI = sessionInfo()
     GGIRversion = c()
     GGIRversion = SI$otherPkgs$GGIR$Version
     if (length(GGIRversion) == 0) GGIRversion = "GGIR not used"
-    filesummary[(vi+5)] = GGIRversion #"2014-03-14 12:14:00 GMT"
-    s_names[vi:(vi+5)] = as.character(c(paste0("data exclusion stategy (value=1, ignore specific hours;",
+    filesummary[(vi+6)] = GGIRversion #"2014-03-14 12:14:00 GMT"
+    s_names[vi:(vi+6)] = as.character(c(paste0("data exclusion stategy (value=1, ignore specific hours;",
                                               " value=2, ignore all data before the first midnight and",
                                               " after the last midnight)"),
                                         "n hours ignored at start of meas (if strategy=1)",
                                         "n hours ignored at end of meas (if strategy=1)",
                                         "n days of measurement after which all data is ignored (if strategy=1)",
                                         "epoch size to which acceleration was averaged (seconds)",
-                                        "GGIR version"))
-    vi = vi + 5
+                                        "if_hip_long_axis_id", "GGIR version"))
+    vi = vi + 6
   }
   rm(LD); rm(ID)
   # tidy up daysummary object
