@@ -29,7 +29,26 @@ g.extractheadervars = function(I) {
       SX = hvalues[which(hnames == "Sex")] #gender
       deviceSerialNumber = hvalues[which(hnames == "Device Unique Serial Code")] #serial number			
     }
-  } else if (mon == "actigraph" | mon == "axivity") { #todo: create automatic extraction of information from actigraph fileheader
+  } else if (mon == "actigraph") {
+    deviceSerialNumber = as.character(I$header$value[which(row.names(I$header) == "Serial Number:")])
+    if (length(deviceSerialNumber) == 0) deviceSerialNumber = "not extracted" #serial number
+    
+    # try to extract firmware version and append it to serial number,
+    # at a later point in time this could become a separate variable in the reports
+    firmwareversion = unlist(strsplit(unlist(strsplit(as.character(I$header$value[1]),"Firmware[.]"))[2],"[.]date"))[1]
+    if (length(firmwareversion) == 1) deviceSerialNumber = paste0(deviceSerialNumber,"_firmware_",firmwareversion)
+    ID = "not extracted"	# volunteer ID as stored in binary file header
+    iID = "not extracted" #investigator ID
+    HN = "not extracted" #handedness
+    BodyLocation = "not extracted" #body location
+    SX = "not extracted" #gender
+    
+  } else if (mon == "axivity" | mon == "movisens") { #todo: create automatic extraction of information from actigraph fileheader
+    if (mon  == "actigraph") {
+      deviceSerialNumber = as.character(I$header$value[which(row.names(I$header) == "Serial Number:")])
+    }
+    
+    
     ID = "not extracted"	# volunteer ID as stored in binary file header
     iID = "not extracted" #investigator ID
     HN = "not extracted" #handedness
@@ -57,4 +76,4 @@ g.extractheadervars = function(I) {
     }
   }
   invisible(list(ID=ID,iID=iID,HN=HN,BodyLocation=BodyLocation,SX=SX,deviceSerialNumber=deviceSerialNumber)) #  wdayname=wdayname,wdaycode=wdaycode,wday=wday,ws3=ws3,ws2=ws2
-}
\ No newline at end of file
+}
