@@ -3,6 +3,8 @@ g.getM5L5 = function(varnum,ws3,t0_LFMF,t1_LFMF,M5L5res,winhr, qM5L5  = c()) {
   # note: acceleration 1-6am removed from this function and placed in g.analyse because it is not related to M5L5 analyse (23-7-2019)
   meanVarnum = mean(varnum)
   do.M5L5 = meanVarnum > 0 # & length(varnum) > 1440*(60/ws3)
+  if (length(do.M5L5) == 0) do.M5L5 = FALSE
+  if (is.na(do.M5L5) == TRUE) do.M5L5 = FALSE
   if (do.M5L5 == TRUE) { # only do the analysis if varnum has values other than zero
     reso = M5L5res #resolution at 5 minutes
     nwindow_f = (t1_LFMF-winhr) - t0_LFMF #number of windows for L5M5 analyses
