@@ -1,13 +1,16 @@
 g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
                      daylimit=FALSE,offset=c(0,0,0),scale=c(1,1,1),tempoffset = c(0,0,0),
-                     do.bfen=FALSE,do.enmo=TRUE,do.lfenmo=FALSE,
-                     do.en=FALSE,do.hfen=FALSE,
+                     do.bfen=FALSE, do.enmo=TRUE, do.lfenmo=FALSE,
+                     do.en=FALSE, do.hfen=FALSE,
                      do.hfenplus=FALSE, do.mad=FALSE,
-                     do.anglex=FALSE,do.angley=FALSE,do.anglez=FALSE,
-                     do.roll_med_acc_x=FALSE,do.roll_med_acc_y=FALSE,do.roll_med_acc_z=FALSE,
-                     do.dev_roll_med_acc_x=FALSE,do.dev_roll_med_acc_y=FALSE,do.dev_roll_med_acc_z=FALSE,do.enmoa=FALSE,
-                     do.lfen=FALSE,
-                     lb = 0.2, hb = 15,  n = 4,meantempcal=c(),chunksize=c(),selectdaysfile=c(),
+                     do.anglex=FALSE, do.angley=FALSE, do.anglez=FALSE,
+                     do.roll_med_acc_x=FALSE, do.roll_med_acc_y=FALSE, do.roll_med_acc_z=FALSE,
+                     do.dev_roll_med_acc_x=FALSE, do.dev_roll_med_acc_y=FALSE,
+                     do.dev_roll_med_acc_z=FALSE, do.enmoa=FALSE,
+                     do.lfen=FALSE, do.lfx=FALSE, do.lfy=FALSE, do.lfz=FALSE,
+                     do.hfx=FALSE, do.hfy=FALSE, do.hfz=FALSE,
+                     do.bfx=FALSE, do.bfy=FALSE, do.bfz=FALSE,
+                     lb = 0.2, hb = 15,  n = 4,meantempcal=c(), chunksize=c(), selectdaysfile=c(),
                      dayborder=0,dynrange=c(),configtz=c(),myfun=c(),...) {
   #get input variables
   input = list(...)
@@ -51,14 +54,18 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
                           do.hfenplus, do.mad,do.anglex,do.angley,do.anglez,
                           do.roll_med_acc_x, do.roll_med_acc_y,do.roll_med_acc_z,
                           do.dev_roll_med_acc_x, do.dev_roll_med_acc_y,
-                          do.dev_roll_med_acc_z, do.enmoa,do.lfen, stringsAsFactors = TRUE)
+                          do.dev_roll_med_acc_z, do.enmoa,do.lfen,
+                          do.lfx, do.lfy, do.lfz,
+                          do.hfx, do.hfy, do.hfz,
+                          do.bfx, do.bfy, do.bfz, stringsAsFactors = TRUE)
   if (length(chunksize) == 0) chunksize = 1
   if (chunksize > 1.5) chunksize = 1.5
   if (chunksize < 0.2) chunksize = 0.2
   nmetrics = sum(c(do.bfen,do.enmo,do.lfenmo,do.en,do.hfen,do.hfenplus,do.mad,
                    do.anglex,do.angley,do.anglez,
                    do.roll_med_acc_x,do.roll_med_acc_y,do.roll_med_acc_z,
-                   do.dev_roll_med_acc_x,do.dev_roll_med_acc_y,do.dev_roll_med_acc_z,do.enmoa,do.lfen))
+                   do.dev_roll_med_acc_x, do.dev_roll_med_acc_y, do.dev_roll_med_acc_z,do.enmoa, do.lfen,
+                   do.lfx, do.lfy, do.lfz,  do.hfx, do.hfy, do.hfz,  do.bfx, do.bfy, do.bfz))
   if (length(myfun) != 0) {
     nmetrics = nmetrics + length(myfun$colnames)
     # check myfun object already, because we do not want to discover
@@ -75,7 +82,7 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
   ws3 = windowsizes[1] ; ws2 = windowsizes[2]; ws = windowsizes[3]  #window sizes
   if ((ws2/60) != round(ws2/60)) {
     ws2 = as.numeric(60 * round(ws2/60))
-    cat("\nWARNING: The long windowsize needs to be a multitude of five minutes periods. The\n")
+    cat("\nWARNING: The long windowsize needs to be a multitude of 1 minute periods. The\n")
     cat(paste("\nlong windowsize has now been automatically adjusted to: ",ws2," seconds in order to meet this criteria.\n",sep=""))
   }
   if ((ws2/ws3) != round(ws2/ws3)) {
@@ -88,9 +95,9 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
   windowsizes = c(ws3,ws2,ws)
   data = PreviousEndPage = starttime = wday = weekdays = wdayname = c()
 
-  monnames = c("genea","geneactive","actigraph","axivity","unknown") #monitor names
+  monnames = c("genea","geneactive","actigraph","axivity","movisens") #monitor names
   filequality = data.frame(filetooshort=FALSE,filecorrupt=FALSE,
-  filedoesnotholdday = FALSE,NFilePagesSkipped = 0, stringsAsFactors = TRUE)
+                           filedoesnotholdday = FALSE,NFilePagesSkipped = 0, stringsAsFactors = TRUE)
   i = 1 #counter to keep track of which binary block is being read
   count = 1 #counter to keep track of the number of seconds that have been read
   count2 = 1 #count number of blocks read with length "ws2" (long epoch, 15 minutes by default)
@@ -132,6 +139,18 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
   mon = INFI$monc
   dformat = INFI$dformc
   sf = INFI$sf
+  hvars = g.extractheadervars(INFI)
+  deviceSerialNumber = hvars$deviceSerialNumber
+  if (mon == 3) { 
+    # If Actigraph then try to specify dynamic range based on Actigraph model
+    if (length(grep(pattern = "CLE", x = deviceSerialNumber)) == 1) {
+      dynrange = 6
+    } else if (length(grep(pattern = "MOS", x = deviceSerialNumber)) == 1) {
+      dynrange = 8
+    } else if (length(grep(pattern = "NEO", x = deviceSerialNumber)) == 1) {
+      dynrange = 6
+    }
+  }
   if (length(sf) == 0) { # if sf is not available then try to retrieve sf from rmc.sf
     if (length(rmc.sf) == 0) {
       stop("Could not identify sample frequency")
@@ -151,27 +170,29 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
 
   ID = g.getidfromheaderobject(filename=filename,header=header,dformat=dformat,mon=mon)
   # get now-wear, clip, and blocksize parameters (thresholds)
-  ncb_params = get_nw_clip_block_params(chunksize, dynrange, mon, rmc.noise, sf, dformat)
+  ncb_params = get_nw_clip_block_params(chunksize, dynrange, mon, rmc.noise, sf, dformat,  rmc.dynamic_range)
   clipthres = ncb_params$clipthres
   blocksize = ncb_params$blocksize
   sdcriter = ncb_params$sdcriter
   racriter = ncb_params$racriter
-
+  n_decimal_places = 4 # number of decimal places to which features should be rounded
   #creating matrixes for storing output
   S = matrix(0,0,4) #dummy variable needed to cope with head-tailing succeeding blocks of data
   nev = 80*10^7 # number expected values
   # NR = ceiling((90*10^6) / (sf*ws3)) + 1000 #NR = number of 'ws3' second rows (this is for 10 days at 80 Hz)
   NR = ceiling(nev / (sf*ws3)) + 1000 #NR = number of 'ws3' second rows (this is for 10 days at 80 Hz)
   metashort = matrix(" ",NR,(1+nmetrics)) #generating output matrix for acceleration signal
-  if (mon == 1 | mon == 3 | (mon == 4 & dformat == 3) | (mon == 4 & dformat == 2) | (mon == 5 & length(rmc.col.temp) == 0)) {
+  if (mon == 1 | mon == 3 | (mon == 4 & dformat == 3) | (mon == 4 & dformat == 2) | (mon == 0 & length(rmc.col.temp) == 0)) {
     temp.available = FALSE
-  } else if (mon == 2 | (mon == 4 & dformat == 4)  | (mon == 5 & length(rmc.col.temp) > 0)){
+  } else if (mon == 2 | (mon == 4 & dformat == 4)  | mon == 5 | (mon == 0 & length(rmc.col.temp) > 0)){
     temp.available = TRUE
   }
   if (temp.available == FALSE) {
     metalong = matrix(" ",((nev/(sf*ws2))+100),4) #generating output matrix for 15 minutes summaries
-  } else if (temp.available == TRUE){
+  } else if (temp.available == TRUE & mon != 5){
     metalong = matrix(" ",((nev/(sf*ws2))+100),7) #generating output matrix for 15 minutes summaries
+  } else if (temp.available == TRUE & mon == 5){
+    metalong = matrix(" ",((nev/(sf*ws2))+100),5) #generating output matrix for 15 minutes summaries
   }
   #------------------------------------------
   if (length(unlist(strsplit(datafile,"[.]RD"))) > 1) {
@@ -227,7 +248,13 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
       NFilePagesSkipped = filequality$NFilePagesSkipped
       switchoffLD = accread$switchoffLD
       PreviousEndPage = accread$endpage
+      PreviousStartPage = accread$startpage
       rm(accread); gc()
+      if(mon == 5) { # if movisens, then read temperature
+        temperature = g.readtemp_movisens(datafile, desiredtz, PreviousStartPage, PreviousEndPage)
+        P = cbind(P, temperature[1:nrow(P)])
+        colnames(P)[4] = "temp"
+        }
     } else {
       filetooshort = FALSE
       filecorrupt = FALSE
@@ -264,6 +291,8 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
           }
         } else if (dformat == 5) {
           data = P$data
+        } else if (mon == 5) {
+          data = as.matrix(P)
         }
         #add left over data from last time
         if (nrow(S) > 0) {
@@ -271,7 +300,7 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
         }
         SWMT = get_starttime_weekday_meantemp_truncdata(temp.available, mon, dformat,
                                                         data, selectdaysfile,
-                                                            P, header, desiredtz,
+                                                        P, header, desiredtz,
                                                         sf, i, datafile,  ws2,
                                                         starttime, wday, weekdays, wdayname)
         starttime=SWMT$starttime
@@ -303,7 +332,7 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
           }
           if ((LD - use) > 1) {
             # reading csv files
-            S = data[(use+1):LD,] #store left over
+            S = as.matrix(data[(use+1):LD,]) #store left over (included as.matrix)
             if (ncol(S) == 1) {
               S = t(S)
             }
@@ -318,18 +347,20 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
           durexp = nrow(data) / (sf*ws)	#duration of experiment in hrs
           data = as.matrix(data)
           #--------------------------------------------
-          if (mon == 2 | (mon == 4 & dformat == 4) | (mon == 5 & length(rmc.col.temp) > 0)) {
+          if (mon == 2 | (mon == 4 & dformat == 4) | mon == 5 | (mon == 0 & length(rmc.col.temp) > 0)) {
             if (mon == 2) {
               temperaturecolumn = 7; lightcolumn = 5
             } else if (mon ==4) {
               temperaturecolumn = 5; lightcolumn = 7
-            } else if (mon ==5) {
+            } else if (mon == 5) {
+              temperaturecolumn = 4
+            } else if (mon ==0) {
               temperaturecolumn = 5
             }
-            if (mon != 5) {
+            if (mon != 0 & mon != 5) {
               light = as.numeric(data[,lightcolumn])
             }
-            if (mon == 5 & length(rmc.col.wear) > 0) {
+            if (mon == 0 & length(rmc.col.wear) > 0) {
               wearcol = as.character(data[, which(colnames(data) == "wear")])
               suppressWarnings(storage.mode(wearcola) <- "logical")
             }
@@ -351,8 +382,14 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
             data[,1:3] = scale(as.matrix(data[,1:3]),center = -offset, scale = 1/scale) +
               scale(yy, center = rep(meantemp,3), scale = 1/tempoffset)  #rescale data
             rm(yy); gc()
+          } else if(mon == 5) {
+            yy = as.matrix(cbind(as.numeric(data[,4]),as.numeric(data[,4]),as.numeric(data[,4])))
+            data = data[,1:3]
+            data[,1:3] = scale(as.matrix(data[,1:3]),center = -offset, scale = 1/scale) +
+              scale(yy, center = rep(meantemp,3), scale = 1/tempoffset)  #rescale data
+            rm(yy); gc()
           } else if ((dformat == 2 | dformat == 5) & (mon != 4)) {
-            if (mon == 2 | (mon == 5 & use.temp == TRUE)) {
+            if (mon == 2 | (mon == 0 & use.temp == TRUE)) {
               tempcolumnvalues = as.numeric(as.character(data[,temperaturecolumn]))
               yy = as.matrix(cbind(tempcolumnvalues, tempcolumnvalues, tempcolumnvalues))
               meantemp = mean(as.numeric(data[,temperaturecolumn]))
@@ -365,9 +402,9 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
                 data = apply(data, 2,as.numeric)
               }
             }
-            if ((mon == 3 | mon == 5) & use.temp == FALSE) {
+            if ((mon == 3 | mon == 0) & use.temp == FALSE) {
               data[,1:3] = scale(data[,1:3],center = -offset, scale = 1/scale)  #rescale data
-            } else if ((mon == 2 | mon == 5) & use.temp == TRUE) {
+            } else if ((mon == 2 | mon == 0) & use.temp == TRUE) {
               # meantemp replaced by meantempcal # 19-12-2013
               data[,1:3] = scale(data[,1:3],center = -offset, scale = 1/scale) +
                 scale(yy, center = rep(meantempcal,3), scale = 1/tempoffset)  #rescale data
@@ -381,17 +418,24 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
           # data[,1], data[,2], data[,3], starttime, (temperature, light)
           if (length(selectdaysfile) > 0) {
             path3 = paste(outputdir,outputfolder,sep="") #where is output stored?
+            raw_output_dir = paste0(path3,"/meta/raw")
+            if (!dir.exists(raw_output_dir)) {
+              dir.create(raw_output_dir)
+            }
             # calculate extra timestamp in a more complete format
             # i am doing this here and not at the top of the code, because at this point the starttime has already be adjusted
             # to the starttime of the first epoch in the data
             # starttime_aschar_tz = strftime(as.POSIXlt(as.POSIXct(starttime),tz=desiredtz),format="%Y-%m-%d %H:%M:%S %z")
-            if (mon == 2 | (mon == 4 & dformat == 4) | (dformat == 5 & mon == 5)) {
+            if (mon == 2 | (mon == 4 & dformat == 4) | (dformat == 5 & mon == 0)) {
               I = INFI
               save(I,sf,wday,wdayname,decn,data,starttime,temperature,light,
-                   file = paste(path3,"/meta/raw/",filename,"_day",i,".RData",sep=""))
+                   file = paste0(raw_output_dir,"/",filename,"_day",i,".RData",sep=""))
+            } else if (mon == 5) {
+              save(I,sf,wday,wdayname,decn,data,starttime,temperature,
+                   file = paste0(raw_output_dir,"/",filename,"_day",i,".RData",sep=""))
             } else {
               save(I,sf,wday,wdayname,decn,data,starttime,
-                   file = paste(path3,"/meta/raw/",filename,"_day",i,".RData",sep=""))
+                   file = paste0(raw_output_dir,"/",filename,"_day",i,".RData",sep=""))
             }
           }
         } else {
@@ -399,26 +443,38 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
           data = cbind(rep(0,nrow(data)),data)
           LD = nrow(data)
         }
-        EN = sqrt(data[,1]^2 + data[,2]^2 + data[,3]^2)
+        EN = sqrt(data[,1]^2 + data[,2]^2 + data[,3]^2) # Do not delete Used for long epoch calculation
         allmetrics = g.applymetrics(data = data,n=n,sf=sf,ws3=ws3,metrics2do=metrics2do, lb=lb,hb=hb)
-        BFEN3b = allmetrics$BFEN3b
-        ENMO3b = allmetrics$ENMO3b
-        ENMOa3b = allmetrics$ENMOa3b
-        LFENMO3b = allmetrics$LFENMO3b
-        EN3b = allmetrics$EN3b
-        HFEN3b = allmetrics$HFEN3b
-        HFENplus3b = allmetrics$HFENplus3b
-        MAD3b = allmetrics$MAD3b
-        angle_x3b = allmetrics$angle_x3b
-        angle_y3b = allmetrics$angle_y3b
-        angle_z3b = allmetrics$angle_z3b
-        roll_med_acc_x3b = allmetrics$roll_med_acc_x3b
-        roll_med_acc_y3b = allmetrics$roll_med_acc_y3b
-        roll_med_acc_z3b = allmetrics$roll_med_acc_z3b
-        dev_roll_med_acc_x3b = allmetrics$dev_roll_med_acc_x3b
-        dev_roll_med_acc_y3b = allmetrics$dev_roll_med_acc_y3b
-        dev_roll_med_acc_z3b = allmetrics$dev_roll_med_acc_z3b
-        LFEN3b = allmetrics$LFEN3b
+        # round decimal places, because due to averaging we get a lot of information
+        # that only slows down computation and increases storage size
+        allmetrics = lapply(allmetrics,round,n_decimal_places)
+        BFEN = allmetrics$BFEN
+        ENMO = allmetrics$ENMO
+        ENMOa = allmetrics$ENMOa
+        LFENMO = allmetrics$LFENMO
+        EN_shortepoch = allmetrics$EN
+        HFEN = allmetrics$HFEN
+        HFENplus = allmetrics$HFENplus
+        MAD = allmetrics$MAD
+        angle_x = allmetrics$angle_x
+        angle_y = allmetrics$angle_y
+        angle_z = allmetrics$angle_z
+        roll_med_acc_x = allmetrics$roll_med_acc_x
+        roll_med_acc_y = allmetrics$roll_med_acc_y
+        roll_med_acc_z = allmetrics$roll_med_acc_z
+        dev_roll_med_acc_x = allmetrics$dev_roll_med_acc_x
+        dev_roll_med_acc_y = allmetrics$dev_roll_med_acc_y
+        dev_roll_med_acc_z = allmetrics$dev_roll_med_acc_z
+        LFEN = allmetrics$LFEN
+        HFX =  allmetrics$HFX
+        HFY =  allmetrics$HFY
+        HFZ =  allmetrics$HFZ
+        LFX =  allmetrics$LFX
+        LFY =  allmetrics$LFY
+        LFZ =  allmetrics$LFZ
+        BFX =  allmetrics$BFX
+        BFY =  allmetrics$BFY
+        BFZ =  allmetrics$BFZ
         #--------------------------------------------------------------------
         if (length(myfun) != 0) { # apply external function to the data to extract extra features
           #starttime
@@ -444,58 +500,85 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
         }
         col_msi = 2
         if (do.bfen == TRUE) {
-          metashort[count:(count-1+length(BFEN3b)),col_msi] = BFEN3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(BFEN)),col_msi] = BFEN; col_msi = col_msi + 1
         }
         if (do.enmo == TRUE) {
-          metashort[count:(count-1+length(ENMO3b)),col_msi] = ENMO3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(ENMO)),col_msi] = ENMO; col_msi = col_msi + 1
         }
         if (do.lfenmo == TRUE) {
-          metashort[count:(count-1+length(LFENMO3b)),col_msi] = LFENMO3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(LFENMO)),col_msi] = LFENMO; col_msi = col_msi + 1
         }
         if (do.en == TRUE) {
-          metashort[count:(count-1+length(EN3b)),col_msi] = EN3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(EN_shortepoch)),col_msi] = EN_shortepoch; col_msi = col_msi + 1
         }
         if (do.hfen == TRUE) {
-          metashort[count:(count-1+length(HFEN3b)),col_msi] = HFEN3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(HFEN)),col_msi] = HFEN; col_msi = col_msi + 1
         }
         if (do.hfenplus == TRUE) {
-          metashort[count:(count-1+length(HFENplus3b)),col_msi] = HFENplus3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(HFENplus)),col_msi] = HFENplus; col_msi = col_msi + 1
         }
         if (do.mad == TRUE) {
-          metashort[count:(count-1+length(MAD3b)),col_msi] = MAD3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(MAD)),col_msi] = MAD; col_msi = col_msi + 1
         }
         if (do.anglex == TRUE) {
-          metashort[count:(count-1+length(angle_x3b)),col_msi] = angle_x3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(angle_x)),col_msi] = angle_x; col_msi = col_msi + 1
         }
         if (do.angley == TRUE) {
-          metashort[count:(count-1+length(angle_y3b)),col_msi] = angle_y3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(angle_y)),col_msi] = angle_y; col_msi = col_msi + 1
         }
         if (do.anglez == TRUE) {
-          metashort[count:(count-1+length(angle_z3b)),col_msi] = angle_z3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(angle_z)),col_msi] = angle_z; col_msi = col_msi + 1
         }
         if (do.roll_med_acc_x == TRUE) {
-          metashort[count:(count-1+length(roll_med_acc_x3b)),col_msi] = roll_med_acc_x3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(roll_med_acc_x)),col_msi] = roll_med_acc_x; col_msi = col_msi + 1
         }
         if (do.roll_med_acc_y == TRUE) {
-          metashort[count:(count-1+length(roll_med_acc_y3b)),col_msi] = roll_med_acc_y3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(roll_med_acc_y)),col_msi] = roll_med_acc_y; col_msi = col_msi + 1
         }
         if (do.roll_med_acc_z == TRUE) {
-          metashort[count:(count-1+length(roll_med_acc_z3b)),col_msi] = roll_med_acc_z3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(roll_med_acc_z)),col_msi] = roll_med_acc_z; col_msi = col_msi + 1
         }
         if (do.dev_roll_med_acc_x == TRUE) {
-          metashort[count:(count-1+length(dev_roll_med_acc_x3b)),col_msi] = dev_roll_med_acc_x3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(dev_roll_med_acc_x)),col_msi] = dev_roll_med_acc_x; col_msi = col_msi + 1
         }
         if (do.dev_roll_med_acc_y == TRUE) {
-          metashort[count:(count-1+length(dev_roll_med_acc_y3b)),col_msi] = dev_roll_med_acc_y3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(dev_roll_med_acc_y)),col_msi] = dev_roll_med_acc_y; col_msi = col_msi + 1
         }
         if (do.dev_roll_med_acc_z == TRUE) {
-          metashort[count:(count-1+length(dev_roll_med_acc_z3b)),col_msi] = dev_roll_med_acc_z3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(dev_roll_med_acc_z)),col_msi] = dev_roll_med_acc_z; col_msi = col_msi + 1
         }
         if (do.enmoa == TRUE) {
-          metashort[count:(count-1+length(ENMOa3b)),col_msi] = ENMOa3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(ENMOa)),col_msi] = ENMOa; col_msi = col_msi + 1
         }
         if (do.lfen == TRUE) {
-          metashort[count:(count-1+length(LFEN3b)),col_msi] = LFEN3b; col_msi = col_msi + 1
+          metashort[count:(count-1+length(LFEN)),col_msi] = LFEN; col_msi = col_msi + 1
+        }
+        if (do.lfx == TRUE) {
+          metashort[count:(count-1+length(LFX)),col_msi] = LFX; col_msi = col_msi + 1
+        }
+        if (do.lfy == TRUE) {
+          metashort[count:(count-1+length(LFY)),col_msi] = LFY; col_msi = col_msi + 1
+        }
+        if (do.lfz == TRUE) {
+          metashort[count:(count-1+length(LFZ)),col_msi] = LFZ; col_msi = col_msi + 1
+        }
+        if (do.hfx == TRUE) {
+          metashort[count:(count-1+length(HFX)),col_msi] = HFX; col_msi = col_msi + 1
+        }
+        if (do.hfy == TRUE) {
+          metashort[count:(count-1+length(HFY)),col_msi] = HFY; col_msi = col_msi + 1
+        }
+        if (do.hfz == TRUE) {
+          metashort[count:(count-1+length(HFZ)),col_msi] = HFZ; col_msi = col_msi + 1
+        }
+        if (do.bfx == TRUE) {
+          metashort[count:(count-1+length(BFX)),col_msi] = BFX; col_msi = col_msi + 1
+        }
+        if (do.bfy == TRUE) {
+          metashort[count:(count-1+length(BFY)),col_msi] = BFY; col_msi = col_msi + 1
+        }
+        if (do.bfz == TRUE) {
+          metashort[count:(count-1+length(BFZ)),col_msi] = BFZ; col_msi = col_msi + 1
         }
 
         if (length(myfun) != 0) { # if an external function is applied.
@@ -503,7 +586,7 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
           metashort[count:(count-1+nrow(OutputExternalFunction)),col_msi:(col_msi+NcolEF)] = as.matrix(OutputExternalFunction); col_msi = col_msi + NcolEF + 1
         }
 
-        count = count + length(EN3b) #increasing "count" the indicator of how many seconds have been read
+        count = count + length(EN_shortepoch) #increasing "count" the indicator of how many seconds have been read
         rm(allmetrics)
         # update blocksize depending on available memory
         BlocksizeNew = updateBlocksize(blocksize=blocksize, bsc_qc=bsc_qc)
@@ -565,8 +648,9 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
         col_mli = 2
         metalong[count2:((count2-1)+nrow(NWav)),col_mli] = NWav; col_mli = col_mli + 1
         metalong[(count2):((count2-1)+nrow(NWav)),col_mli] = CWav; col_mli = col_mli + 1
-        if (mon == 2 | (mon == 4 & dformat == 4)) { #going from sample to ws2
-          #light (running mean)
+        if (mon == 2 | (mon == 4 & dformat == 4) | mon == 5) { #going from sample to ws2
+          if (mon == 2 | (mon == 4 & dformat == 4)) {
+            #light (running mean)
           lightc = cumsum(c(0,light))
           select = seq(1,length(lightc),by=(ws2*sfold))
           lightmean = diff(lightc[round(select)]) / abs(diff(round(select)))
@@ -580,6 +664,7 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
             } else {
               lightmax[li] = max(light[((li-1)*(ws2*sfold)):(li*(ws2*sfold))])
             }
+           }
           }
           #temperature (running mean)
           temperaturec = cumsum(c(0,temperature))
@@ -593,11 +678,18 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
         ENb = diff(ENc[round(select)]) / abs(diff(round(select)))
         rm(ENc, EN); gc()
         if (mon == 2 | (mon == 4 & dformat == 4)) {
-          metalong[(count2):((count2-1)+nrow(NWav)),col_mli] = lightmean; col_mli= col_mli + 1
-          metalong[(count2):((count2-1)+nrow(NWav)),col_mli] = lightmax; col_mli= col_mli + 1
-          metalong[(count2):((count2-1)+nrow(NWav)),col_mli] = temperatureb; col_mli= col_mli + 1
+          metalong[(count2):((count2-1)+nrow(NWav)),col_mli] = round(lightmean, digits=n_decimal_places)
+          col_mli= col_mli + 1
+          metalong[(count2):((count2-1)+nrow(NWav)),col_mli] = round(lightmax, digits=n_decimal_places)
+          col_mli= col_mli + 1
+          metalong[(count2):((count2-1)+nrow(NWav)),col_mli] = round(temperatureb, digits=n_decimal_places)
+          col_mli= col_mli + 1
+        } else if (mon == 5) {
+          metalong[(count2):((count2-1)+nrow(NWav)),col_mli] = round(temperatureb, digits=n_decimal_places)
+          col_mli= col_mli + 1
         }
-        metalong[(count2):((count2-1)+nrow(NWav)),col_mli] = ENb; col_mli= col_mli + 1
+        metalong[(count2):((count2-1)+nrow(NWav)),col_mli] = round(ENb, digits=n_decimal_places)
+        col_mli= col_mli + 1
         count2  = count2 + nmin
         if (exists("data")) rm(data)
         if (exists("light")) rm(light)
@@ -654,7 +746,14 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
         }
         hvars = g.extractheadervars(I)
         deviceSerialNumber = hvars$deviceSerialNumber
-        SDFi = which(as.numeric(SDF$Monitor) == as.numeric(deviceSerialNumber))
+        options(warn=-1)
+        char_deviceSerialNumber = is.na(as.numeric(deviceSerialNumber))
+        options(warn=0)
+        if (char_deviceSerialNumber ==  FALSE) {
+          SDFi = which(as.numeric(SDF$Monitor) == as.numeric(deviceSerialNumber))
+        } else {
+          SDFi = which(SDF$Monitor == deviceSerialNumber)
+        }
         dateday1 = as.character(SDF[SDFi,2])
         dateday2 = as.character(SDF[SDFi,3])
         dtday1 = as.POSIXlt(paste0(dateday1," 01:00:00"),format="%d/%m/%Y %H:%M:%S")
@@ -709,9 +808,10 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
                             rmc.header.structure = rmc.header.structure,
                             rmc.check4timegaps = rmc.check4timegaps)
         }
-        hvars = g.extractheadervars(I)
-        deviceSerialNumber = hvars$deviceSerialNumber
-        SDFi = which(as.numeric(SDF$Monitor) == as.numeric(deviceSerialNumber))
+        # Next three lines commented out, because this was also calculated 50 lines earlier
+        # hvars = g.extractheadervars(I)
+        # deviceSerialNumber = hvars$deviceSerialNumber
+        # SDFi = which(as.numeric(SDF$Monitor) == as.numeric(deviceSerialNumber))
         if (length(SDFi) == 1) { # if deviceSerialNumber is not in the file then this is skipped
           dateday1 = as.character(SDF[SDFi,2])
           dateday2 = as.character(SDF[SDFi,3])
@@ -733,12 +833,15 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
     }
     metricnames_short = c("timestamp","BFEN","ENMO","LFENMO","EN","HFEN","HFENplus","MAD",
                           "anglex","angley","anglez","roll_med_acc_x","roll_med_acc_y","roll_med_acc_z",
-                          "dev_roll_med_acc_x","dev_roll_med_acc_y","dev_roll_med_acc_z","ENMOa","LFEN") #
+                          "dev_roll_med_acc_x","dev_roll_med_acc_y","dev_roll_med_acc_z","ENMOa","LFEN",
+                          "LFX", "LFY", "LFZ", "HFX", "HFY", "HFZ", "BFX", "BFY", "BFZ") #
     metricnames_short = as.character(metricnames_short[c(TRUE,do.bfen,do.enmo,do.lfenmo,do.en,do.hfen,do.hfenplus,do.mad,
                                                          do.anglex,do.angley,do.anglez,
                                                          do.roll_med_acc_x,do.roll_med_acc_y,do.roll_med_acc_z,
                                                          do.dev_roll_med_acc_x,do.dev_roll_med_acc_y,do.dev_roll_med_acc_z,
-                                                         do.enmoa,do.lfen)])
+                                                         do.enmoa,do.lfen,
+                                                         do.lfx, do.lfy, do.lfz, do.hfx, do.hfy, do.hfz,
+                                                         do.bfx, do.bfy, do.bfz)])
     # Following code is needed to make sure that algorithms that produce character value
     # output are not assumed to be numeric
     NbasicMetrics = length(metricnames_short)
@@ -752,10 +855,12 @@ g.getmeta = function(datafile,desiredtz = "",windowsizes = c(5,900,3600),
     for (ncolms in 2:NbasicMetrics) {
       metashort[,ncolms] = as.numeric(metashort[,ncolms])
     }
-    if (mon == 1 | mon == 3 | (mon == 4 & dformat == 3) | (mon == 4 & dformat == 2) | (mon == 5 & use.temp == FALSE)) {
+    if (mon == 1 | mon == 3 | (mon == 4 & dformat == 3) | (mon == 4 & dformat == 2) | (mon == 0 & use.temp == FALSE)) {
       metricnames_long = c("timestamp","nonwearscore","clippingscore","en")
-    } else if (mon == 2 | (mon == 4 & dformat == 4)  | (mon == 5 & use.temp == TRUE)) {
+    } else if (mon == 2 | (mon == 4 & dformat == 4)  | (mon == 0 & use.temp == TRUE)) {
       metricnames_long = c("timestamp","nonwearscore","clippingscore","lightmean","lightpeak","temperaturemean","EN")
+    } else if (mon == 5) {
+      metricnames_long = c("timestamp","nonwearscore","clippingscore","temperaturemean","EN")
     }
     metalong = data.frame(A = metalong, stringsAsFactors = FALSE)
     names(metalong) = metricnames_long
