@@ -6,7 +6,9 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
                    do.enmoa = FALSE,
                    do.roll_med_acc_x=FALSE,do.roll_med_acc_y=FALSE,do.roll_med_acc_z=FALSE,
                    do.dev_roll_med_acc_x=FALSE,do.dev_roll_med_acc_y=FALSE,do.dev_roll_med_acc_z=FALSE,
-                   do.lfen = FALSE,
+                   do.lfen = FALSE, do.lfx=FALSE, do.lfy=FALSE, do.lfz=FALSE, 
+                   do.hfx=FALSE, do.hfy=FALSE, do.hfz=FALSE, 
+                   do.bfx=FALSE, do.bfy=FALSE, do.bfz=FALSE, 
                    do.cal = TRUE,
                    lb = 0.2, hb = 15,  n = 4, spherecrit=0.3,
                    minloadcrit=72,printsummary=TRUE,print.filename=FALSE,overwrite=FALSE,
@@ -73,6 +75,8 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
   } else {
     useRDA = FALSE
   }
+  # check whether these are movisens files
+  is.mv = ismovisens(datadir)
   # create output directory if it does not exist
   if (filelist == TRUE | useRDA == TRUE) {
     if (length(studyname) == 0) {
@@ -108,6 +112,10 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
                    dir(datadir,recursive=TRUE,pattern="[.]bin", full.names = TRUE),
                    dir(datadir,recursive=TRUE,pattern="[.]wav", full.names = TRUE),
                    dir(datadir,recursive=TRUE,pattern="[.]cwa", full.names = TRUE))
+    if(is.mv == TRUE) {
+      fnamesfull = dir(datadir,recursive=TRUE,pattern="acc.bin", full.names = TRUE)
+      fnames = dir(datadir, recursive = FALSE)
+      }
   } else {
     fnamesfull = datadir
   }
@@ -146,16 +154,22 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
   }
   tmp5 = tmp6 = rep(0,length(fnamesfull))
   if (length(fnamesfull) > 0) {
-    fnamesshort = apply(X=as.matrix(fnamesfull),MARGIN=1,FUN=f16)
-    phase = apply(X=as.matrix(fnamesfull),MARGIN=1,FUN=f17)
-    for (i in 1:length(fnames)) {
-      ff = unlist(strsplit(fnames[i],"/"))
-      ff = ff[length(ff)]
-      if (length(which(fnamesshort == ff)) > 0) {
-        tmp5[i] = fnamesfull[which(fnamesshort == ff)]
-        tmp6[i] = phase[which(fnamesshort == ff)]
+    if(is.mv == FALSE) {
+      fnamesshort = apply(X=as.matrix(fnamesfull),MARGIN=1,FUN=f16)
+      phase = apply(X=as.matrix(fnamesfull),MARGIN=1,FUN=f17)
+      for (i in 1:length(fnames)) {
+        ff = unlist(strsplit(fnames[i],"/"))
+        ff = ff[length(ff)]
+        if (length(which(fnamesshort == ff)) > 0) {
+          tmp5[i] = fnamesfull[which(fnamesshort == ff)]
+          tmp6[i] = phase[which(fnamesshort == ff)]
+        }
+      }
+    } else if (is.mv == TRUE) {
+      tmp5 = fnamesfull
+      phase = apply(X=as.matrix(fnamesfull),MARGIN=1,FUN=f17)
+      tmp6 = phase
       }
-    }
   } else {
     stop(paste0("\nNo files to analyse. Check that there are accelerometer files",
                 "in the directory specified with argument datadir"))
@@ -192,7 +206,8 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
       Nmetrics2calc = do.bfen + do.enmo + do.lfenmo + do.lfen + do.en + do.hfen + do.hfenplus + do.mad +
         do.anglex + do.angley + do.anglez + do.roll_med_acc_x + do.roll_med_acc_y +
         do.roll_med_acc_z + do.dev_roll_med_acc_x + do.dev_roll_med_acc_y +
-        do.dev_roll_med_acc_z + do.enmoa
+        do.dev_roll_med_acc_z + do.enmoa + do.lfx + do.lfy + do.lfz + do.hfx + 
+        do.hfy + do.hfz + do.bfx +  do.bfy + do.bfz
       if (Nmetrics2calc > 4) { #Only give warning when user wants more than 4 metrics.
         warning(paste0("\nExtracting many metrics puts higher demands on memory. Please consider",
                        " reducing the value for argument chunksize or setting do.parallel to FALSE"))
@@ -229,13 +244,12 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
                          "g.binread", "g.cwaread", "g.readaccfile", "g.wavread", "g.downsample", "updateBlocksize",
                          "g.getidfromheaderobject", "g.getstarttime", "POSIXtime2iso8601", "chartime2iso8601",
                          "iso8601chartime2POSIX", "g.metric", "datadir2fnames", "read.myacc.csv",
-                         "get_nw_clip_block_params", "get_starttime_weekday_meantemp_truncdata")
+                         "get_nw_clip_block_params", "get_starttime_weekday_meantemp_truncdata", "ismovisens")
     errhand = 'stop'
     # Note: This will not work for cwa files, because those also need Rcpp functions.
     # So, it is probably best to turn off parallel when debugging cwa data.
   }
   `%myinfix%` = ifelse(do.parallel, foreach::`%dopar%`, foreach::`%do%`) # thanks to https://stackoverflow.com/questions/43733271/how-to-switch-programmatically-between-do-and-dopar-in-foreach
-  #,'GENEAread','mmap', 'signal'
   output_list =foreach::foreach(i=f0:f1, .packages = packages2passon,
                                 .export=functions2passon, .errorhandling=errhand) %myinfix% {
     tryCatchResult = tryCatch({
@@ -473,19 +487,26 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
                       do.hfen=do.hfen,
                       do.hfenplus=do.hfenplus,
                       do.mad=do.mad,
-                      do.anglex=do.anglex,do.angley=do.angley,do.anglez=do.anglez,
-                      do.roll_med_acc_x=do.roll_med_acc_x,do.roll_med_acc_y=do.roll_med_acc_y,do.roll_med_acc_z=do.roll_med_acc_z,
-                      do.dev_roll_med_acc_x=do.dev_roll_med_acc_x,do.dev_roll_med_acc_y=do.dev_roll_med_acc_y,do.dev_roll_med_acc_z=do.dev_roll_med_acc_z,
+                      do.anglex=do.anglex, do.angley=do.angley, do.anglez=do.anglez,
+                      do.roll_med_acc_x=do.roll_med_acc_x,
+                      do.roll_med_acc_y=do.roll_med_acc_y,
+                      do.roll_med_acc_z=do.roll_med_acc_z,
+                      do.dev_roll_med_acc_x=do.dev_roll_med_acc_x, 
+                      do.dev_roll_med_acc_y=do.dev_roll_med_acc_y, 
+                      do.dev_roll_med_acc_z=do.dev_roll_med_acc_z,
                       do.enmoa=do.enmoa,
+                      do.lfx=do.lfx, do.lfy=do.lfy, do.lfz=do.lfz, 
+                      do.hfx=do.hfx, do.hfy=do.hfy, do.hfz=do.hfz,
+                      do.bfx=do.bfx, do.bfy=do.bfy, do.bfz=do.bfz, 
                       lb = lb, hb = hb,  n = n,
-                      desiredtz=desiredtz,daylimit=daylimit,windowsizes=windowsizes,
-                      tempoffset=C$tempoffset,scale=C$scale,offset=C$offset,
-                      meantempcal=C$meantempcal,chunksize=chunksize,
+                      desiredtz=desiredtz, daylimit=daylimit, windowsizes=windowsizes,
+                      tempoffset=C$tempoffset, scale=C$scale, offset=C$offset,
+                      meantempcal=C$meantempcal, chunksize=chunksize,
                       selectdaysfile=selectdaysfile,
                       outputdir=outputdir,
                       outputfolder=outputfolder,
-                      dayborder=dayborder,dynrange=dynrange,
-                      rmc.dec=rmc.dec,configtz=configtz,
+                      dayborder=dayborder, dynrange=dynrange,
+                      rmc.dec=rmc.dec, configtz=configtz,
                       rmc.firstrow.acc = rmc.firstrow.acc,
                       rmc.firstrow.header = rmc.firstrow.header,
                       rmc.header.length = rmc.header.length,
@@ -525,7 +546,14 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
         metadatadir = c()
         if (length(datadir) > 0) {
           # list of all csv and bin files
-          fnames = datadir2fnames(datadir,filelist) #GGIR::
+          if (is.mv == TRUE) {
+            for (filei in 1:length(fnames)) {
+              fnames[[filei]] = strsplit(fnames[[filei]], "/")[[1]][1]
+            }
+            fnames = unique(fnames)
+          } else if(is.mv == FALSE){
+            fnames = datadir2fnames(datadir,filelist) #GGIR::
+          }
           # check whether these are RDA
           if (length(unlist(strsplit(fnames[1],"[.]RD"))) > 1) {
             useRDA = TRUE
